@@ -14,6 +14,7 @@ def get_index(a, b):
         inx_converse (list or int): The index of the given elements in the list a.
     """
 
+
     inx = []
     inx_converse = []
     # Check the type of the given element, whether it is a single one or several items.
@@ -24,11 +25,10 @@ def get_index(a, b):
                 inx_converse.append(a.index(x))
             except ValueError:
                 pass
+        return inx, inx_converse
     else:
         try:
             inx.append(b.index(a))
-            inx_converse.append(a.index(a))
         except ValueError:
             pass
-
-    return inx, inx_converse
\ No newline at end of file
+        return inx
\ No newline at end of file
